// Written by Jason Heddings: http://mapit.mozdev.org/
// License: http://creativecommons.org/licenses/by-nc-sa/2.0/

var gMapIt = null;

////////////////////////////////////////////////////////////////////////////////
// Saves all settings to internal preferences.

function flush() {
  // general settings
  gMapItSettings.mapper = document.getElementById("mapper").selectedItem.value;
  gMapItSettings.target = document.getElementById("target").selectedItem.value;
  gMapItSettings.verify = document.getElementById("verify").selectedItem.value;

  // save all the regular expressions
  var regexps = new Array();
  var listbox = document.getElementById("regexps");
  for (var idx = 0; idx < listbox.getRowCount(); idx++) {
    regexps.push(listbox.getItemAtIndex(idx).value);
  }
  gMapItSettings.regexps = regexps;
} //END: flush()

////////////////////////////////////////////////////////////////////////////////
// Sets all UI components based on saved internal settings.

function reload() {
  // general settings
  document.getElementById("mapper").selectedItem =
    document.getElementById(gMapItSettings.mapper);
  document.getElementById("target").selectedItem =
    document.getElementById(gMapItSettings.target);
  document.getElementById("verify").selectedItem =
    document.getElementById(gMapItSettings.verify);

  // populate all the regular expressions
  var regexps = gMapItSettings.regexps;
  var listbox = document.getElementById("regexps");
  for (var idx = 0; idx < regexps.length; idx++) {
    listbox.appendItem(regexps[idx], regexps[idx]);
  }
} //END: reload()

////////////////////////////////////////////////////////////////////////////////
// Toggle buttons that relate to the regexp list.

function updateRegexpButtons() {
  var listbox = document.getElementById("regexps");
  var textbox = document.getElementById("add-re");

  document.getElementById("move-up").disabled = (listbox.selectedIndex <= 0);
  document.getElementById("move-down").disabled = (listbox.selectedIndex < 0)
                                                || (listbox.selectedIndex > listbox.getRowCount() - 2);

  document.getElementById("add-regexp").disabled = (textbox.textLength <= 0);
  document.getElementById("remove-regexp").disabled = (listbox.selectedIndex < 0);
}

////////////////////////////////////////////////////////////////////////////////
// Remove the currently selected regular expression.

function removeRegexp() {
  var listbox = document.getElementById("regexps");
  var textbox = document.getElementById("add-re");
  var index = listbox.selectedIndex;
  var item = listbox.removeItemAt(index);
  listbox.selectedIndex = index - 1;
  textbox.value = item.value;
  updateRegexpButtons();
}

////////////////////////////////////////////////////////////////////////////////
// Adds the text in the new box to the bottom of the list.

function addRegexp() {
  var listbox = document.getElementById("regexps");
  var textbox = document.getElementById("add-re");
  var item = listbox.appendItem(textbox.value, textbox.value);
  listbox.ensureElementIsVisible(item);
  listbox.selectedIndex = listbox.getIndexOfItem(item);
  textbox.value = "";
  updateRegexpButtons();
}

////////////////////////////////////////////////////////////////////////////////
// Move the selected item up in the list.

function moveUp() {
  var listbox = document.getElementById("regexps");
  var index = listbox.selectedIndex;
  var item = listbox.removeItemAt(index);
  listbox.insertItemAt(index - 1, item.label, item.value);
  listbox.ensureIndexIsVisible(index - 1);
  listbox.selectedIndex = index - 1;
  updateRegexpButtons();
}

////////////////////////////////////////////////////////////////////////////////
// Move the selected item down in the list.

function moveDown() {
  var listbox = document.getElementById("regexps");
  var index = listbox.selectedIndex;
  var item = listbox.removeItemAt(index);
  listbox.insertItemAt(index + 1, item.label, item.value);
  listbox.ensureIndexIsVisible(index + 1);
  listbox.selectedIndex = index + 1;
  updateRegexpButtons();
}

////////////////////////////////////////////////////////////////////////////////
// Event Handler: called when "Ok" button is pressed.

function onOK() {
  flush();
} //END: onOK

////////////////////////////////////////////////////////////////////////////////


function onLoad() {
  gMapItSettings = new MapItSettings();
  reload();
} //END: onLoad
